summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--apps/wps-display.c16
1 files changed, 14 insertions, 2 deletions
diff --git a/apps/wps-display.c b/apps/wps-display.c
index 841196f..10a4ca0 100644
--- a/apps/wps-display.c
+++ b/apps/wps-display.c
@@ -343,7 +343,7 @@ static char* get_dir(char* buf, int buf_size, const char* path, int level)
/* Get the tag specified by the two characters at fmt.
*
* id3 - ID3 data to get tag values from.
* nid3 - next-song ID3 data to get tag values from.
* tag - string (of two characters) specifying the tag to get.
* buf - buffer to certain tags, such as track number, play time or
@@ -660,8 +660,20 @@ static char* get_tag(struct mp3entry* cid3,
return buf;
}
break;
+ case 'r': /* Runtime database Information */
+ switch(tag[1])
+ {
+ case 'p': /* Playcount */
+ *flags |= WPS_REFRESH_STATIC;
+ snprintf(buf, buf_size, "%ld", cid3->playcount);
+ return buf;
+ case 'r': /* Rating */
+ *flags |= WPS_REFRESH_STATIC;
+ snprintf(buf, buf_size, "%d", cid3->rating);
+ return buf;
+ }
+ break;
}
-
return NULL;
}
@@ -343,7 +343,7 @@ static char* get_dir(char* buf, int buf_size, const char* path, int level)
/* Get the tag specified by the two characters at fmt.
*
- * id3 - ID3 data to get tag values from.
+ * cid3 - ID3 data to get tag values from.
* nid3 - next-song ID3 data to get tag values from.
* tag - string (of two characters) specifying the tag to get.